function PDFCallback(obj, event)
% PDFCallback - Callback called by a MatlabServer object for generating a
% .pdf file as response
% 
% CALL:
%     PDFCallback(obj, event)
% 
% INPUT:
%     obj: 
%         handle to the MatlabServer object which triggered the callback
%     event: 
%         ServerEvent with query and response information
% 
% OUTPUT:
%     No output
%
%   Copyright 2006-2013 Modelit, www.modelit.nl

try 
    % Generate the response
    response = readBytesFromFile(fullfile(pwd, 'MatlabWebserver.pdf'));
        
    % Return response to the client
    sendResponse(event, response,...
        'contenttype', 'application/pdf')  % The MIME type   
catch me
    %In case of error, sent error message in HTM format
    sendResponse(event, errorMessage(me.message),...
        'statuscode', 500,...              % Statuscode 500: Interval Server Error
        'contenttype', 'text/html')  % The MIME type       
end
%__________________________________________________________________________
function text = errorMessage(msg)
% errorMessage - Make an HTML error message
% 
% CALL:
%  text = errorMessage(msg)
text = {'<html><center>'
    sprintf('<h1 >%s</h1>',datestr(now))
    sprintf('<h2 style="color:red">%s</h2>',msg)
    '</center></html>'};
text = [text{:}];



    