function installwebservice
%entrypoint of webservice. This module will install the webservice.

%compile command (save results in directory "exe_webserver"):
%mcc -m -C -d exe_webserver installwebservice

%Assist end users with setting the classpath right
if ~verifyClasspathFile{'MatlabServer.jar'}
    return
end

%Define some globals to keep track of the webservice status
global N      %total number of calls
global E      %total number of errors
global TCALL  %instant of last call

N=0;
E=0;
TCALL=now;

% Create a server on the specified port, port should be a port specified in
% the web.xml in the matlabserver directory in the Tomcat root
server = createMatlabServer(4444);
% Set callback to be executed when server receives a request from client
set(server, 'ServerInvokedCallback', @webserviceCallback);
% Start the webservice
server.startServer;

%Start loop to prevent the program from returning to cmd window. Everry 15
%minutes, display a status update in the console
while 1
    disp(sprintf('%s:  #calls: %d   #errors: %d   Last call: %s',...
        datestr(now),N,E,datestr(TCALL)));
    pause(900) %wait 15 minutes
end
%__________________________________________________________________________
function webserviceCallback(obj, event)
% webserviceCallback - Callback called by a MatlabServer object
%
% CALL:
%     webserviceCallback(obj, event)
%
% INPUT:
%     obj:
%         handle to the MatlabServer object which triggered the callback
%     event:
%         ServerEvent with query and response information
%
% OUTPUT:
%     No output
%
% Copyright 2008 - 2015 Modelit, www.modelit.nl

global N      %total number of calls
global E      %total number of errors
global TCALL  %instant of last call

% It's good practice to always surround the callback with try catch
% and always return an answer to the client
try
    N=N+1;
    TCALL=now;
    % Collect some request information
    S = event2struct(event);
    % Generate the response
    response = HTML(S);
    
    % Return response to the client
    sendResponse(event, response,...
        'contenttype','text/html') % The MIME type
catch me
    E=E+1;
    sendResponse(event, errorMessage(me.message),...
        'statuscode', 500,'contenttype','text/html') % The MIME type
end
%__________________________________________________________________________
function text = HTML(S)
% HTML - Make a simple HTML string
%
% CALL:
% text = HTML(S)

disp(S.RequestQueryString);

GETArguements = parseQueryString(S.RequestQueryString);
for k=1:length(GETArguements)
    input.(GETArguements(k).name)=GETArguements(k).value;
end

%Verify input arg "x" was specified
if ~isfield(input,'x')
    error('Input argument "x" is required'); %==> jump to catch
end
   
%Verify input arg "y" was specified
if ~isfield(input,'y')
    error('Input argument "y" is required'); %==> jump to catch
end

text = {'<html><center>'
    sprintf('<h1>%s</h1>',datestr(now))
    sprintf('<h2>HTTP: %s</h2>',S.RequestMethod)
    sprintf('<h2>Query: %s</h2>',S.RequestQueryString)
    sprintf('<h2>From: %s</h2>',S.RemoteAddr)
    sprintf('<h2>CPA: %s</h2>',...
    num2str(addition(str2double(input.x),str2double(input.y))))
    '</center></html>'};
text = [text{:}];
%__________________________________________________________________________
function text = errorMessage(msg)
% errorMessage - Make an HTML error message
%
% CALL:
% text = errorMessage(msg)
text = { '<html><center>'
    sprintf('<h1 >%s</h1>',datestr(now))
    sprintf('<h2 style="color:red">%s</h2>',msg)
    '</center></html>'};
text = [text{:}];
%__________________________________________________________________________
function result = addition(x,y)
result = x+y;

